# yais

Yet Another Image Scraper

## Changelog

### v0.2.1

- Fix support for pixiv urls startswith `https://pixiv.net/`

### v0.2.0

- Add support for tweet with multiple images. ( e.g. https://twitter.com/hunwaritoast/status/1188048064948293632 )
- Add support for zerochan.net
